---
hide:
  - navigation
  - toc
---

<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

You may also be interested in:

**My projects**

- [Translate Horizon: Zero Dawn](https://github.com/jonathanfox5/translate_horizon_zero_dawn): A set of python scripts to build priming and reference materials directly from the game files.
- [Plot Vowel Space](https://github.com/jonathanfox5/plot_vowel_space): A set of python scripts to plot your vowel positions and compare them against reference audio.
- [LemonTizer](https://github.com/jonathanfox5/lemon_tizer): A python library that wraps the `spacy` lemmatiser for use in other language learning tools.

**Other projects**

- [Anki](https://apps.ankiweb.net): A powerful and customisable flashcard tool.
- [Vocabsieve](https://github.com/FreeLanguageTools/vocabsieve/): A very useful sentence mining tool.
- [asbplayer](https://chromewebstore.google.com/detail/asbplayer-language-learni/hkledmpjpaehamkiehglnbelcpdflcab?pli=1): A video player well suited for sentence mining and manipulating on screen subtitles within your browser.
- [Lute](https://github.com/LuteOrg/lute-v3): An immersion learning tool, focused on written materials.
